#' Ensembl IDs from GTEx V6 Gene Read Count Data
#'
#' A dataset containing the Ensembl IDs from GTEx (V6)
#' gene read count data.
#'
#' @format A character vector with 56,318 Ensembl IDs.
#' @source \url{https://www.gtexportal.org}
"gtexv6"

#' Ensembl IDs from GTEx V6p Gene Read Count Data
#'
#' A dataset containing the Ensembl IDs from GTEx (V6p)
#' gene read count data.
#'
#' @format A character vector with 56,238 Ensembl IDs.
#' @source \url{https://www.gtexportal.org}
"gtexv6p"

#' Ensembl IDs from GTEx V7 Gene Read Count Data
#'
#' A dataset containing the Ensembl IDs from GTEx (V7)
#' gene read count data.
#'
#' @format A character vector with 56,202 Ensembl IDs.
#' @source \url{https://www.gtexportal.org}
"gtexv7"
